@@ -1,9 +1,9 @@
 /*
  * gaim - Gadu-Gadu Protocol Plugin
- * $Id: gg.c,v 1.74 2003/08/25 15:42:38 lschiere Exp $
+ * $Id: gg.c,v 1.95 2004/04/22 01:53:12 chipx86 Exp $
  *
  * Copyright (C) 2001 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -34,9 +34,6 @@
 #include "server.h"
 #include "util.h"
 
-/* XXX for g_show_info_text(), WEBSITE, and stuff */
-#include "gaim.h"
-
 #define GG_CONNECT_STEPS 5
 
 #define AGG_BUF_LEN 1024
@@ -89,7 +86,7 @@ static gchar *charset_convert(const gchar *locstr, const char *encsrc, const cha
 static gboolean invalid_uin(const char *uin)
 {
 	unsigned long int res = strtol(uin, (char **)NULL, 10);
-	if (res == LONG_MIN || res == LONG_MAX || res == 0)
+	if (res == ULONG_MAX || res == 0)
 		return TRUE;
 	return FALSE;
 }
@@ -251,7 +248,7 @@ static GList *agg_buddy_menu(GaimConnection *gc, const char *who)
 {
 	GList *m = NULL;
 	struct proto_buddy_menu *pbm;
-	struct buddy *b = gaim_find_buddy(gc->account, who);
+	GaimBuddy *b = gaim_find_buddy(gc->account, who);
 	static char buf[AGG_BUF_LEN];
 
 	if (!b) {
@@ -307,16 +304,19 @@ static void main_callback(gpointer data, gint source, GaimInputCondition cond)
 	case GG_EVENT_MSG:
 		{
 			gchar *imsg;
+			gchar *jmsg;
 			gchar user[20];
 
 			g_snprintf(user, sizeof(user), "%lu", e->event.msg.sender);
 			if (!allowed_uin(gc, user))
 				break;
 			imsg = charset_convert(e->event.msg.message, "CP1250", "UTF-8");
-			strip_linefeed(imsg);
+			gaim_str_strip_cr(imsg);
+			jmsg = gaim_escape_html(imsg);
 			/* e->event.msg.time - we don't know what this time is for */
-			serv_got_im(gc, user, imsg, 0, time(NULL), -1);
+			serv_got_im(gc, user, jmsg, 0, time(NULL));
 			g_free(imsg);
+			g_free(jmsg);
 		}
 		break;
 	case GG_EVENT_NOTIFY:
@@ -560,7 +560,7 @@ static void agg_close(GaimConnection *gc)
 	g_free(gc->proto_data);
 }
 
-static int agg_send_im(GaimConnection *gc, const char *who, const char *msg, int len, GaimImFlags flags)
+static int agg_send_im(GaimConnection *gc, const char *who, const char *msg, GaimConvImFlags flags)
 {
 	struct agg_data *gd = (struct agg_data *)gc->proto_data;
 	gchar *imsg;
@@ -582,7 +582,7 @@ static int agg_send_im(GaimConnection *gc, const char *who, const char *msg, int
 	return 1;
 }
 
-static void agg_add_buddy(GaimConnection *gc, const char *who)
+static void agg_add_buddy(GaimConnection *gc, const char *who, GaimGroup *group)
 {
 	struct agg_data *gd = (struct agg_data *)gc->proto_data;
 	if (invalid_uin(who))
@@ -668,7 +668,7 @@ static void search_results(GaimConnection *gc, gchar *webdata)
 			g_free(oldibuf);
 			break;
 		case 2:
-			ibuf = g_strconcat(oldibuf, "<B>", _("First name"), ":</B> ", p, "<BR>\n", NULL);
+			ibuf = g_strconcat(oldibuf, "<B>", _("First Name"), ":</B> ", p, "<BR>\n", NULL);
 			g_free(oldibuf);
 			break;
 		case 3:
@@ -684,10 +684,10 @@ static void search_results(GaimConnection *gc, gchar *webdata)
 			/* Hack, invalid_uin does what we really want here but may change in future */
 			if (invalid_uin(p))
 				ibuf =
-				    g_strconcat(oldibuf, "<B>", _("Birth year"), ":</B> <BR>\n", NULL);
+				    g_strconcat(oldibuf, "<B>", _("Birth Year"), ":</B> <BR>\n", NULL);
 			else
 				ibuf =
-				    g_strconcat(oldibuf, "<B>", _("Birth year"), ":</B> ", p, "<BR>\n",
+				    g_strconcat(oldibuf, "<B>", _("Birth Year"), ":</B> ", p, "<BR>\n",
 						NULL);
 			g_free(oldibuf);
 			break;
@@ -722,11 +722,18 @@ static void search_results(GaimConnection *gc, gchar *webdata)
 
 	g_strfreev(webdata_tbl);
 
-	g_show_info_text(gc, NULL, 2, buf, NULL);
+	gaim_notify_formatted(gc, NULL, _("Buddy Information"), NULL,
+						  buf, NULL, NULL);
 
 	g_free(buf);
 }
 
+static void
+change_pass(GaimConnection *gc)
+{
+	gaim_account_request_change_password(gaim_connection_get_account(gc));
+}
+
 static void import_buddies_server_results(GaimConnection *gc, gchar *webdata)
 {
 	gchar *ptr;
@@ -773,8 +780,8 @@ static void import_buddies_server_results(GaimConnection *gc, gchar *webdata)
 		gaim_debug(GAIM_DEBUG_MISC, "gg",
 				   "import_buddies_server_results: uin: %s\n", name);
 		if (!gaim_find_buddy(gc->account, name)) {
-			struct buddy *b;
-			struct group *g;
+			GaimBuddy *b;
+			GaimGroup *g;
 			/* Default group if none specified on server */
 			gchar *group = g_strdup("Gadu-Gadu");
 			if (strlen(data_tbl[5])) {
@@ -791,7 +798,7 @@ static void import_buddies_server_results(GaimConnection *gc, gchar *webdata)
 				gaim_blist_add_group(g, NULL);
 			}
 			b = gaim_buddy_new(gc->account, name, strlen(show) ? show : NULL);
-			gaim_blist_add_buddy(b,g,NULL);
+			gaim_blist_add_buddy(b,NULL,g,NULL);
 			gaim_blist_save();
 			g_free(group);
 		}
@@ -952,7 +959,7 @@ static void http_req_callback(gpointer data, gint source, GaimInputCondition con
 			      "User-Agent: " GG_HTTP_USERAGENT "\r\n"
 			      "Content-Length: %d\r\n"
 			      "Pragma: no-cache\r\n" "\r\n" "%s\r\n",
-			      hdata->form, hdata->host, strlen(request), request);
+			      hdata->form, hdata->host, (int)strlen(request), request);
 
 	g_free(request);
 
@@ -1006,7 +1013,7 @@ static void export_buddies_server(GaimConnection *gc)
 	gchar *u = gg_urlencode(gaim_account_get_username(gc->account));
 	gchar *p = gg_urlencode(gaim_account_get_password(gc->account));
 
-	GaimBlistNode *gnode, *bnode;
+	GaimBlistNode *gnode, *cnode, *bnode;
 
 	he->gc = gc;
 	he->type = AGG_HTTP_USERLIST_EXPORT;
@@ -1018,42 +1025,46 @@ static void export_buddies_server(GaimConnection *gc)
 	g_free(p);
 
 	for(gnode = gaim_get_blist()->root; gnode; gnode = gnode->next) {
-		struct group *g = (struct group *)gnode;
+		GaimGroup *g = (GaimGroup *)gnode;
 		int num_added=0;
 		if(!GAIM_BLIST_NODE_IS_GROUP(gnode))
 			continue;
-		for(bnode = gnode->child; bnode; bnode = bnode->next) {
-			struct buddy *b = (struct buddy *)bnode;
-
-			if(!GAIM_BLIST_NODE_IS_BUDDY(bnode))
+		for(cnode = gnode->child; cnode; cnode = cnode->next) {
+			if(!GAIM_BLIST_NODE_IS_CONTACT(cnode))
 				continue;
+			for(bnode = cnode->child; bnode; bnode = bnode->next) {
+				GaimBuddy *b = (GaimBuddy *)bnode;
 
-			if(b->account == gc->account) {
-				gchar *newdata;
-				/* GG Number */
-				gchar *name = gg_urlencode(b->name);
-				/* GG Pseudo */
-				gchar *show = gg_urlencode(b->alias ? b->alias : b->name);
-				/* Group Name */
-				gchar *gname = gg_urlencode(g->name);
+				if(!GAIM_BLIST_NODE_IS_BUDDY(bnode))
+					continue;
 
-				ptr = he->request;
-				newdata = g_strdup_printf("%s;%s;%s;%s;%s;%s;%s",
-						show, show, show, show, "", gname, name);
+				if(b->account == gc->account) {
+					gchar *newdata;
+					/* GG Number */
+					gchar *name = gg_urlencode(b->name);
+					/* GG Pseudo */
+					gchar *show = gg_urlencode(b->alias ? b->alias : b->name);
+					/* Group Name */
+					gchar *gname = gg_urlencode(g->name);
 
-				if(num_added > 0)
-					he->request = g_strconcat(ptr, "%0d%0a", newdata, NULL);
-				else
-					he->request = g_strconcat(ptr, newdata, NULL);
+					ptr = he->request;
+					newdata = g_strdup_printf("%s;%s;%s;%s;%s;%s;%s",
+							show, show, show, show, "", gname, name);
 
-				num_added++;
+					if(num_added > 0)
+						he->request = g_strconcat(ptr, "%0d%0a", newdata, NULL);
+					else
+						he->request = g_strconcat(ptr, newdata, NULL);
 
-				g_free(newdata);
-				g_free(ptr);
+					num_added++;
 
-				g_free(gname);
-				g_free(show);
-				g_free(name);
+					g_free(newdata);
+					g_free(ptr);
+
+					g_free(gname);
+					g_free(show);
+					g_free(name);
+				}
 			}
 		}
 	}
@@ -1182,6 +1193,7 @@ static GList *agg_actions(GaimConnection *gc)
 	GList *m = NULL;
 	struct proto_actions_menu *pam;
 
+#if 0
 	pam = g_new0(struct proto_actions_menu, 1);
 	pam->label = _("Directory Search");
 	pam->callback = show_find_info;
@@ -1189,10 +1201,11 @@ static GList *agg_actions(GaimConnection *gc)
 	m = g_list_append(m, pam);
 
 	m = g_list_append(m, NULL);
+#endif
 
 	pam = g_new0(struct proto_actions_menu, 1);
 	pam->label = _("Change Password");
-	pam->callback = show_change_passwd;
+	pam->callback = change_pass;
 	pam->gc = gc;
 	m = g_list_append(m, pam);
 
@@ -1254,12 +1267,12 @@ static void agg_get_info(GaimConnection *gc, const char *who)
 	}
 }
 
-static const char *agg_list_icon(GaimAccount *a, struct buddy *b)
+static const char *agg_list_icon(GaimAccount *a, GaimBuddy *b)
 {
 	return "gadu-gadu";
 }
 
-static void agg_list_emblems(struct buddy *b, char **se, char **sw, char **nw, char **ne)
+static void agg_list_emblems(GaimBuddy *b, char **se, char **sw, char **nw, char **ne)
 {
 	int status;
 	if (b->present == GAIM_BUDDY_OFFLINE)
@@ -1292,7 +1305,7 @@ static GaimPlugin *my_protocol = NULL;
 
 static GaimPluginProtocolInfo prpl_info =
 {
-	GAIM_PROTO_GADUGADU,
+	GAIM_PRPL_API_VERSION,
 	0,
 	NULL,
 	NULL,
@@ -1313,7 +1326,6 @@ static GaimPluginProtocolInfo prpl_info =
 	agg_set_away,
 	NULL,
 	NULL,
-	NULL,
 	agg_dir_search,
 	NULL,
 	agg_change_passwd,
@@ -1332,6 +1344,7 @@ static GaimPluginProtocolInfo prpl_info =
 	NULL,
 	NULL,
 	NULL,
+	NULL,
 	agg_keepalive,
 	NULL,
 	NULL,
@@ -1341,12 +1354,13 @@ static GaimPluginProtocolInfo prpl_info =
 	NULL,
 	NULL,
 	NULL,
+	NULL,
 	NULL
 };
 
 static GaimPluginInfo info =
 {
-	2,                                                /**< api_version    */
+	GAIM_PLUGIN_API_VERSION,                          /**< api_version    */
 	GAIM_PLUGIN_PROTOCOL,                             /**< type           */
 	NULL,                                             /**< ui_requirement */
 	0,                                                /**< flags          */
